@@ -1,16 +1,17 @@
 from .__main__ import *
-from .utils import coord, clipboard
-from .objects import *
-from .objects_ext import *
-from .validated_objects import *
+from .rTkUtils import *
+from .rTkUtils import _UniqueIdentifiers
+from .cWidgets import *
+from .cWidgets_extended import *
+from .reWidgets import *
+from .rTkForm import qForm
 from .matchart import Chart
 from .flags import *
+from .language import localization
 try:
 	import tkcalendar
-	from .tkCalendar_ext.calendar_ext import DateEntry, cDateEntry, reDateEntry
+	from .rTkCalendar.rTkCalendar import DateEntry, cDateEntry, reDateEntry
 except:
-	print("tkcalendar missing")
-	raise
 	class DateEntry:
 		def __init__(self, master, **kwargs):
 			raise DateEntryNotFoundException
@@ -21,11 +22,16 @@ except:
 		def __init__(self, master, **kwargs):
 			raise DateEntryNotFoundException
 
+from .rTkLogging import rTkLogger
+
+import logging
+logging.setLoggerClass(rTkLogger)
+
 #import types
 #class rTk(types.ModuleType):
 #	@property
 #	def version(self):
-#		version_info = (0, 0, 1)
+#		version_info = (0, 0, 5)
 #		return ".".join([str(x) for x in version_info])
-#__all__ = ['.rapidTk.*', '.objects.*', '.utils.coord']
-__version__ = "0.0.1"
+#__all__ = ['.rapidTk.*', '.cWidgets.*', '.rtkUtils.*']
+__version__ = "0.5"
